diff --git a/.idea/gruppe06-hufflepuff-projekt2-texteditor.iml b/.idea/gruppe06-hufflepuff-projekt2-texteditor.iml
index 0fb1519..324ad0a 100644
--- a/.idea/gruppe06-hufflepuff-projekt2-texteditor.iml
+++ b/.idea/gruppe06-hufflepuff-projekt2-texteditor.iml
@@ -24,5 +24,21 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
\ No newline at end of file
diff --git a/README.md b/README.md
index bca003d..6437956 100644
--- a/README.md
+++ b/README.md
@@ -1,46 +1,70 @@
#Texteditor
-Texteditor is a program to edit a text by in- and output into the console.
-#Usermanual
-#ADD a Textline
+Texteditor is a program to edit a text by using the input and is then able to output it as desired via the console.
+##Usermanual
+###ADD a paragraph
```ADD```
-First please enter the command add to add a new textline. Then enter the text you want to add .
+Adds a paragraph with custom text.
+Enter the command add to add a new paragraph at the end of text. After submitting the add command you will be prompted to enter the text to add as last paragraph.
```ADD [n]```
-If you want to add a textline to a certain paragraph then please use the command add and then enter that paragraphnummber.
-After that enter the text you want to add to that paragraph.
+Adds a paragraph with custom text at a specific position in text.
+Enter the command add with the paragraph number where it should be added.
+After submitting the add [n] command you will be prompted to enter the text to add in the corresponding paragraph.
-#DUMMY Text
+###DUMMY Text
```DUMMY```
-First please enter the command dummy to enter a pre written text into the textline.
+Inserts a paragraph with dummy text at the end of the text.
+Enter the command dummy to enter a pre-written paragraph into the text as your last paragraph.
```DUMMY [n]```
-If you want to enter a pre written dummy text into a specific paragraph then please enter the command dummy and then the paragraph that you want to use.
+Inserts a paragraph with dummy text at a specific position.
+Enter the command dummy with a paragraph number to insert a pre-written dummy text paragraph to a spcific position.
-#REPLACE a Text
+###REPLACE a Text
```REPLACE```
-First please enter the command replace then enter the characters that you want to replace. After that please enter
-the new characters that should replace the old characters.
+Replaces desired words in the last paragraph with a desired replacement.
+Enter the command replace, after submitting the command replace enter the characters that should be replaced. After submitting the characters you will be
+need to input the characters wich will replace the previous characters.
```REPLACE [n]```
-If you want to replace a text from a certain paragraph, please enter the command replace and then enter the characters you want to
-replace. After you entered the characters you want to replace please enter now the new characters that should replace the
-old characters.
+Replaces desired words in the chosen paragraph [n] text with a desired replacement.
+Enter the command replace with a desired paragraph where the characters should be replaced,
+after submitting the command replace enter the characters that should be replaced. After submitting the characters you will be
+need to input the characters wich will replace the previous characters.
-#DELETE a Text
+###DELETE a Text
```DEL```
-First please enter the command del to delete a text. Then please enter the text size you want to delete.
+Deletes the last paragraph.
+Enter the command del to delete the last paragraph.
```DEL [n]```
-If you want to delete a text from a certain paragraph then please enter the command del and then the paragraph that you want to delete.
+Deletes the selected paragraph.
+Enter the command del with a paragraph number, the corresponding paragraph will then be deleted.
-#INDEX
-``ÌNDEX``
-First please enter the command index to show the index.
+###INDEX the words
+```INDEX```
+Diplays the index of words used 3 times or more.
+Enter the command index to display the words that are displayed more than three times in the text with their corresponding paragraphs.
-#Print the Text
+###Print the Text
```PRINT```
-First please enter the command print to print out the current text you have.
+Prints the text with the previously set format option.
+Enter the command print to print out the current text you have. The Text will be printed with the settings set before (see FORMAT the Text).
+If no settings have been set the standard to output is the FIX format and a line length of 20.
-#FORMAT the Text
-```FORMAT```
+###FORMAT the Text
+```FORMAT RAW```
+Sets the format to raw.
+Enter the command format raw to change the print format to raw. After you changed the format to raw you can use the command ```PRINT``` again
+and each paragraph will be printed on one line with its corresponding paragraph number.
+```FORMAT FIX [n]```
+Sets the format fix with the maximum line length.
+Enter the command format fix and the max line length which will be used. After you changed the format to fix you can use the command ```PRINT``` again
+and the text will be displayed with the max length in mind and a new line will be created if no space is left for a paragraph.
+If a word is too long to fit the line length, it will be displayed as whole, ignoring the max length.
+
+
+##Classdiagramm
+
+![Classdiagramm](docs/PM2_ClassDiagram.drawio.svg)
diff --git a/docs/Equivalent.md b/docs/EquivalentClass.md
similarity index 97%
rename from docs/Equivalent.md
rename to docs/EquivalentClass.md
index 83f7ba7..be8eca8 100644
--- a/docs/Equivalent.md
+++ b/docs/EquivalentClass.md
@@ -1,4 +1,4 @@
-#Equivalent
+# Equivalentclass
### Text.java Index method
diff --git a/docs/Kick-off.md b/docs/Kick-off.md
deleted file mode 100644
index 8d980f6..0000000
--- a/docs/Kick-off.md
+++ /dev/null
@@ -1,23 +0,0 @@
-# Projekt TextEditor
-
-## Auftragsaufteilung
-
-**Michael**
-
-- [ ]
-
-**Leonardo**
-
-- [ ]
-
-**Andrin**
-
-- [ ]
-
-**Roman**
-
-- [ ]
-
-**Stefan**
-
-- [ ]
\ No newline at end of file
diff --git a/docs/PM2_ClassDiagram.drawio b/docs/PM2_ClassDiagram.drawio
index 3c57fb8..72c4b65 100644
--- a/docs/PM2_ClassDiagram.drawio
+++ b/docs/PM2_ClassDiagram.drawio
@@ -1 +1 @@
-
\ No newline at end of file
+
\ No newline at end of file
diff --git a/docs/PM2_ClassDiagram.drawio.svg b/docs/PM2_ClassDiagram.drawio.svg
new file mode 100644
index 0000000..72c4b65
--- /dev/null
+++ b/docs/PM2_ClassDiagram.drawio.svg
@@ -0,0 +1 @@
+
\ No newline at end of file
diff --git a/docs/Pflichtenheft.md b/docs/Pflichtenheft.md
index 7ef16b0..db2d0d7 100644
--- a/docs/Pflichtenheft.md
+++ b/docs/Pflichtenheft.md
@@ -2,7 +2,8 @@
## Aufgabe
-Programmieren Sie eine einfache Textverarbeitung mit Ein- und Ausgabe über die Konsole. Diese soll als eigenständige Anwendung laufen und über den folgenden Befehlssatz gesteuert werden:
+Programmieren Sie eine einfache Textverarbeitung mit Ein- und Ausgabe über die Konsole. Diese soll als eigenständige
+Anwendung laufen und über den folgenden Befehlssatz gesteuert werden:
| Befehl | Beschreibung |
| :--- | :--- |
@@ -19,19 +20,29 @@ Programmieren Sie eine einfache Textverarbeitung mit Ein- und Ausgabe über die
## Anforderungen
- Ihre Anwendung muss eigenständig laufen, also durch Aufruf von main() und ohne BlueJ.
-- Schreiben Sie Rückmeldungen zu Fehlern (z.B. «Unbekanntes Kommando») statt auf die Standardausgabe (System.out) auf die Standardfehlerausgabe (Sytem.err). Die Syntax ist analog zu der von System.out bekannten ("System.err.println").
-- Sie dürfen alle in der Vorlesung bis zur Abgabe durchgenommenen Konstrukte benutzen, jedoch nur diese. Dies schliesst insbesondere ein: Allen Stoff im BlueJ-Buch bis und mit Kapitel 9, JUnit Testing, Packages zur Verwaltung Ihres Codes. Es schliesst insbesondere aus: Vererbung, Einbindung von Paketen ausserhalb java.util.*
-- Als "Absatz" definieren wir eine über die unten beschriebene Scanner.nextline() - Methode eingelesenen String. Validieren Sie den erhaltenen Input und filtern Sie alle Sonderzeichen (d.h. der in die Anwendung übernommene Text darf nur Buchstaben, Zahlen, Leerzeichen und Satzzeichen enthalten).
+- Schreiben Sie Rückmeldungen zu Fehlern (z.B. «Unbekanntes Kommando») statt auf die Standardausgabe (System.out) auf
+ die Standardfehlerausgabe (Sytem.err). Die Syntax ist analog zu der von System.out bekannten ("System.err.println").
+- Sie dürfen alle in der Vorlesung bis zur Abgabe durchgenommenen Konstrukte benutzen, jedoch nur diese. Dies schliesst
+ insbesondere ein: Allen Stoff im BlueJ-Buch bis und mit Kapitel 9, JUnit Testing, Packages zur Verwaltung Ihres Codes.
+ Es schliesst insbesondere aus: Vererbung, Einbindung von Paketen ausserhalb java.util.*
+- Als "Absatz" definieren wir eine über die unten beschriebene Scanner.nextline() - Methode eingelesenen String.
+ Validieren Sie den erhaltenen Input und filtern Sie alle Sonderzeichen (d.h. der in die Anwendung übernommene Text
+ darf nur Buchstaben, Zahlen, Leerzeichen und Satzzeichen enthalten).
- Das Einlesen und Abspeichern von Dateien ist in diesem Projekt nicht notwendig.
-- Ihr Code ist in Javadoc (mindestens für Klassen und Public Methods und zusätzlich für Konstruktoren, jedoch generell ohne Getter/Setter) und wo sinnvoll in Zeilenkommentaren zur Funktionalität dokumentiert. Ihr Klassendiagramm ist auf GitHub abgelegt. Die zur Übersetzung und Start nötigen Aufrufe sind separat im README für Ihr Repo dokumentiert.
-- Definieren Sie Unit Tests für die Index-Funktionalität, implementieren Sie diese in JUnit und führen Sie sie aus. Dokumentieren Sie die Tests.
+- Ihr Code ist in Javadoc (mindestens für Klassen und Public Methods und zusätzlich für Konstruktoren, jedoch generell
+ ohne Getter/Setter) und wo sinnvoll in Zeilenkommentaren zur Funktionalität dokumentiert. Ihr Klassendiagramm ist auf
+ GitHub abgelegt. Die zur Übersetzung und Start nötigen Aufrufe sind separat im README für Ihr Repo dokumentiert.
+- Definieren Sie Unit Tests für die Index-Funktionalität, implementieren Sie diese in JUnit und führen Sie sie aus.
+ Dokumentieren Sie die Tests.
- Wenden Sie die relevanten Abschnitte im Clean-Code-Handbuch an.
## Hinweise
- Achten Sie beim Klassenentwurf auf Kohäsion und Kopplung und beachten Sie auch die Hinweise im Clean-Code-Handbuch.
-- Fehlervermeidung und JUnit wird in Programmieren 1 durchgenommen. Planen Sie genügend Zeit ein, um Ihre Tests zu definieren, umzusetzen und allfällige Fehler zu korrigieren.
-- Für Management und Dokumentation von Arbeitsschritten empfehlen wir das Issue Tracking in GitHub. Andere Lösungen sind denkbar.
+- Fehlervermeidung und JUnit wird in Programmieren 1 durchgenommen. Planen Sie genügend Zeit ein, um Ihre Tests zu
+ definieren, umzusetzen und allfällige Fehler zu korrigieren.
+- Für Management und Dokumentation von Arbeitsschritten empfehlen wir das Issue Tracking in GitHub. Andere Lösungen sind
+ denkbar.
- Eine Quelle für Blindtext ist https://lipsum.com/. Andere Texte sind möglich.
## Vorgehen
@@ -48,7 +59,9 @@ Wir empfehlen, etwa folgendermassen vorzugehen:
## Abgabe
-Legen Sie für das Projekt ein Repository gemäss der bereits aus Projekt 1 bekannten Anleitung an. Der von Ihnen erarbeitete Code muss zur Abgabe bis zur bekanntgegebenen Deadline dort hochgeladen werden. Abgaben auf anderen Services (github.com, OneDrive, etc.) werden nicht gewertet.
+Legen Sie für das Projekt ein Repository gemäss der bereits aus Projekt 1 bekannten Anleitung an. Der von Ihnen
+erarbeitete Code muss zur Abgabe bis zur bekanntgegebenen Deadline dort hochgeladen werden. Abgaben auf anderen
+Services (github.com, OneDrive, etc.) werden nicht gewertet.
## Bewertung
@@ -56,24 +69,32 @@ Für diese Aufgabe erhalten Sie maximal 15 Punkte. In die Bewertung fliessen fol
### Allgemeine Anforderung (all-or-nothing)
-- Voraussetzung für Punkterteilung: Das Programm ist lauffähig. (Kriterium: Vorführung oder Test durch Ihre Dozierenden) Ein nicht lauffähiges Programm erhält 0 Punkte.
- Ein lauffähiges Programm wird in den folgenden beiden Bereichen beurteilt. Für Teil- oder Nichterfüllung werden Abzüge in Ansatz gebracht. Das Nichterfüllen einer Unterkategorie kann zum vollständigen Abzug in einem Bereich führen. Es werden keine Negativpunkte vergeben.
-
+- Voraussetzung für Punkterteilung: Das Programm ist lauffähig. (Kriterium: Vorführung oder Test durch Ihre Dozierenden)
+ Ein nicht lauffähiges Programm erhält 0 Punkte. Ein lauffähiges Programm wird in den folgenden beiden Bereichen
+ beurteilt. Für Teil- oder Nichterfüllung werden Abzüge in Ansatz gebracht. Das Nichterfüllen einer Unterkategorie kann
+ zum vollständigen Abzug in einem Bereich führen. Es werden keine Negativpunkte vergeben.
### Bereich Entwicklung
- Ihr Programm besitzt die geforderte Funktionalität. (Vorführung oder Test durch Ihre Dozierenden)
-- Sie halten die Vorgaben hinsichtlich einsetzbarer Konstrukte und Clean Code ein. (Codeanalyse durch Ihre Dozierenden, ggf. Erläuterung)
-- Sie haben eine gute Klassenaufteilung gefunden. Das Klassendiagramm ist auf GitHub mit hochzuladen. (Analyse durch Ihre Dozierenden, ggf. Erläuterung)
-- Sie haben sinnvolle Test Cases für die Funktion Index definiert, diese in JUnit umgesetzt und erfolgreich ausgeführt. (Dokumentation über Test Cases und erfolgreiche Tests, diese sind auf GitHub mit hochzuladen.)
+- Sie halten die Vorgaben hinsichtlich einsetzbarer Konstrukte und Clean Code ein. (Codeanalyse durch Ihre Dozierenden,
+ ggf. Erläuterung)
+- Sie haben eine gute Klassenaufteilung gefunden. Das Klassendiagramm ist auf GitHub mit hochzuladen. (Analyse durch
+ Ihre Dozierenden, ggf. Erläuterung)
+- Sie haben sinnvolle Test Cases für die Funktion Index definiert, diese in JUnit umgesetzt und erfolgreich
+ ausgeführt. (Dokumentation über Test Cases und erfolgreiche Tests, diese sind auf GitHub mit hochzuladen.)
### Bereich Vorgehen und Dokumentation
- Ihr Code ist mit JavaDoc dokumentiert. (s.a. Hinweis unter "Anforderungen", Analyse durch Ihre Dozierenden)
-- Alle Gruppenmitglieder haben in nennenswertem Umfang Code beigetragen und auf GitHub eingecheckt. (Check durch GitHub Log)
+- Alle Gruppenmitglieder haben in nennenswertem Umfang Code beigetragen und auf GitHub eingecheckt. (Check durch GitHub
+ Log)
## Beispielcode zum Konsoleneingabe
-Die Eingabe von Text ist im BlueJ-Buch, Kapitel 6 erwähnt und in Kapitel 14.9. genauer beschrieben. Wenn Sie Probleme bei der Anwendung der Texteingabe haben, wenden Sie sich an Ihre Dozierenden. Die Anwendung der Scanner-Klasse sollte nach dem gegebenen Muster jedoch einfach gelingen.
+
+Die Eingabe von Text ist im BlueJ-Buch, Kapitel 6 erwähnt und in Kapitel 14.9. genauer beschrieben. Wenn Sie Probleme
+bei der Anwendung der Texteingabe haben, wenden Sie sich an Ihre Dozierenden. Die Anwendung der Scanner-Klasse sollte
+nach dem gegebenen Muster jedoch einfach gelingen.
In der Grundfunktionalität sieht sie folgendermassen aus:
@@ -115,4 +136,6 @@ public class InputReaderMod {
}
```
-**Quelle**: Anpassung von InputReader.java (englischsprachige Fassung der im Buch in Kap. 6 erwähnten Klasse EingabeLeser.java) aus dem Unterverzeichnis projects/chapter06/ tech-support-complete im Archiv https://bluej.org/objects-first/resources/projects.zip)
+**Quelle**: Anpassung von InputReader.java (englischsprachige Fassung der im Buch in Kap. 6 erwähnten Klasse
+EingabeLeser.java) aus dem Unterverzeichnis projects/chapter06/ tech-support-complete im
+Archiv https://bluej.org/objects-first/resources/projects.zip)
diff --git a/src/Text.java b/src/Text.java
index 4a46661..dea7aca 100644
--- a/src/Text.java
+++ b/src/Text.java
@@ -2,10 +2,19 @@ import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;
+/**
+ * New class Text
+ * This class saves and edits the text.
+ * Authors: Roman Schenk, Andrin Fassbind
+ * Date: 12.11.2021
+ */
public class Text {
- private final ArrayList text = new ArrayList<>();
private static final String dummyText = "The standard Lorem Ipsum passage, used since the 1500s \"Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.\" Section 1.10.32 of \"de Finibus Bonorum et Malorum\", written by Cicero in 45 BC \"Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque laudantium, totam rem aperiam, eaque ipsa quae ab illo inventore veritatis et quasi architecto beatae vitae dicta sunt explicabo. Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt. Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem. Ut enim ad minima veniam, quis nostrum exercitationem ullam corporis suscipit laboriosam, nisi ut aliquid ex ea commodi consequatur? Quis autem vel eum iure reprehenderit qui in ea voluptate velit esse quam nihil molestiae consequatur, vel illum qui dolorem eum fugiat quo voluptas nulla pariatur?";
+ /**
+ * The DataFields text and dummyText save the objects that are being used in this class.
+ */
+ private final ArrayList text = new ArrayList<>();
/**
* Method to check if a specific paragraph exists.
@@ -39,7 +48,7 @@ public class Text {
* @return returns true if the paragraph is added successfully.
*/
public boolean add(String text) {
- this.text.add(text.replaceAll("[^A-Za-z0-9 .,:?!\"'-]",""));
+ this.text.add(text.replaceAll("[^A-Za-z0-9 .,:?!\"'-]", ""));
return true;
}
@@ -88,14 +97,14 @@ public class Text {
}
/**
- * Method to replace characters in the last paragraph
+ * Method to replace characters in the last paragraph.
*
* @param oldChar the old character.
* @param newChar the new character.
- * @return returns true if the paragraph is changed successfully
+ * @return returns true if the paragraph is changed successfully.
*/
public boolean replace(String oldChar, String newChar) {
- if(paragraphExists(text.size())) {
+ if (paragraphExists(text.size())) {
text.set((text.size() - 1), text.get(text.size() - 1).replace(oldChar, newChar));
return true;
}
@@ -103,11 +112,11 @@ public class Text {
}
/**
- * This method deletes a specific paragraph. As a parameter it uses a int.
+ * This method deletes a specific paragraph. As a parameter it uses an int.
* If the parameter is valid it deletes the specific pararaph otherwise it will return false.
*
- * @param paragraphNumber the Paragraph which should be deleted.
- * @return False: If the int is not a valid paragraph. || True: If the int is a valid paragraph number
+ * @param paragraphNumber the paragraph which should be deleted.
+ * @return False: If the int is not a valid paragraph. || True: If the int is a valid paragraph number.
*/
public boolean del(int paragraphNumber) {
if (paragraphExists(paragraphNumber)) {
@@ -123,7 +132,7 @@ public class Text {
* @return True: if paragraph has been deleted.
*/
public boolean del() {
- if(paragraphExists(text.size())){
+ if (paragraphExists(text.size())) {
text.remove(text.size() - 1);
return true;
}
@@ -138,7 +147,7 @@ public class Text {
* @return ArrayList
*/
public ArrayList index() {
- HashMap> wordbook = new HashMap<>();
+ HashMap> wordbook = new HashMap<>();
createWordlist(wordbook);
String input;
ArrayList output = new ArrayList<>();
@@ -164,38 +173,38 @@ public class Text {
/**
* This method counts all words in text and adds the count together with the paragraph where the word has been used to a Hashmap.
- *
*/
- private void createWordlist(HashMap> wordbook) {
+ private void createWordlist(HashMap> wordbook) {
int counter;
ArrayList numbersList;
String firstLetter;
String restLetters;
for (int i = 0; i < text.size(); i++) {
- String[] words = text.get(i).trim().toLowerCase().split("[ :;.,!?><+*}{)('/\n]+");
+ String[] words = text.get(i).trim().toLowerCase().split("[. ,:?!\"'-]+");
for (String word : words) {
//Words get formatted consistently
- counter = 1;
- firstLetter = word.substring(0, 1);
- restLetters = word.substring(1);
- word = firstLetter.toUpperCase() + restLetters;
- //Words are beeing counted
- if (wordbook.containsKey(word)) {
- numbersList = wordbook.get(word);
- counter = numbersList.get(0);
- numbersList.remove(0);
- numbersList.add(0, counter + 1);
- if (numbersList.get(numbersList.size() - 1) < i + 1) {
+ if (word.length() > 0) {
+ counter = 1;
+ firstLetter = word.substring(0, 1);
+ restLetters = word.substring(1);
+ word = firstLetter.toUpperCase() + restLetters;
+ //Words are beeing counted
+ if (wordbook.containsKey(word)) {
+ numbersList = wordbook.get(word);
+ counter = numbersList.get(0);
+ numbersList.remove(0);
+ numbersList.add(0, counter + 1);
+ if (numbersList.get(numbersList.size() - 1) < i + 1) {
+ numbersList.add(i + 1);
+ }
+ } else {
+ numbersList = new ArrayList<>();
+ numbersList.add(counter);
numbersList.add(i + 1);
}
- } else {
- numbersList = new ArrayList<>();
- numbersList.add(counter);
- numbersList.add(i + 1);
+ wordbook.put(word, numbersList);
}
- wordbook.put(word, numbersList);
}
}
}
-
}
diff --git a/src/TextEditor.java b/src/TextEditor.java
index c5d15c4..82083cf 100644
--- a/src/TextEditor.java
+++ b/src/TextEditor.java
@@ -1,16 +1,18 @@
/**
- * Main class TextEditor
+ * New class TextEditor
+ * This class contains the main method.
+ * Author: Michael Ziegler
+ * Date: 12.11.2021
*/
public class TextEditor {
/**
* Main Method that is connected to the TextLogik class.
+ *
* @param args there are no arguments needed.
*/
-
public static void main(String[] args) {
- TextLogik t = new TextLogik();
-
+ TextLogic t = new TextLogic();
}
}
diff --git a/src/TextInput.java b/src/TextInput.java
index f7f68d9..2d63271 100644
--- a/src/TextInput.java
+++ b/src/TextInput.java
@@ -1,13 +1,32 @@
import java.util.Scanner;
+/**
+ * New class TextInput
+ * This class checks for new command inputs and gets the text input.
+ * Author: Michael Ziegler
+ * Date: 12.11.2021
+ */
public class TextInput {
+ /**
+ * DataField Scanner saves the object that is being used in this class.
+ */
private static final Scanner sc = new Scanner(System.in);
+ /**
+ * Method to check for new input.
+ *
+ * @return the StringArray with the commands.
+ */
public static String[] checkForInput() {
return sc.nextLine().toUpperCase().split(" ");
}
+ /**
+ * Gets the text that has been written.
+ *
+ * @return the next line.
+ */
public static String getTextInput() {
return sc.nextLine();
}
diff --git a/src/TextOutput.java b/src/TextOutput.java
index 0083d52..9b21b07 100644
--- a/src/TextOutput.java
+++ b/src/TextOutput.java
@@ -1,23 +1,25 @@
import java.util.ArrayList;
/**
- *
+ * New class TextOutput
+ * This class puts out the finished text and formats the text if wanted.
+ * Author: Leonardo Brandenberger
+ * Date: 12.11.2021
*/
public class TextOutput {
private boolean formatRaw;
private int columnWidth = 20;
/**
- * Method which checks in which way the paragraphs should be displayed. And then calls the corresponding
+ * Method that checks in which way the paragraphs should be displayed and then calls the corresponding
* method to output the text as desired.
*
* @param text the ArrayList which is then formatted into the desired output.
*/
public void print(ArrayList text) {
- if(text.size() == 0) {
+ if (text.size() == 0) {
errorMissingText();
- }
- else if (formatRaw) {
+ } else if (formatRaw) {
printFormated(text);
} else {
toFormat(text);
@@ -33,7 +35,6 @@ public class TextOutput {
for (int counter = 0; counter < text.size(); counter++) {
System.out.println("<" + (counter + 1) + ">: <" + text.get(counter) + ">");
}
-
}
/**
@@ -48,27 +49,21 @@ public class TextOutput {
String[] words = paragraph.split(" ");
int lastWordNumber = words.length;
int currentWordNumber = 0;
- for(String word : words) {
+ for (String word : words) {
currentWordNumber++;
- if (word.length()<= columnWidth - currentLength) {
- System.out.print(word);
+ if (word.length() >= columnWidth - currentLength && currentWordNumber != 1) {
+ System.out.println();
+ currentLength = 0;
}
- else {
- if(currentWordNumber != 1) {
- System.out.println();
- currentLength = 0;
- }
- System.out.print(word);
-
- }
- if(!(currentWordNumber == lastWordNumber)) {
+ System.out.print(word);
+ if (!(currentWordNumber == lastWordNumber)) {
System.out.print(" ");
currentLength = currentLength + word.length() + 1;
- }
- else {
+ } else {
System.out.println();
}
}
+ System.out.println();
}
}
@@ -83,19 +78,17 @@ public class TextOutput {
}
/**
- * Method to set the formatRaw to false and also set the length of the desired paragraph length in order to limit
+ * Method to set the formatRaw to false and also to set the length of the desired paragraph length in order to limit
* the paragraph length when printing the text.
*
* @param length the paragraph length when printing the text.
- * @return returns true if successful and false if and invalid length has been submitted.
*/
public void formatFix(int length) {
- if(length > 0) {
+ if (length > 0) {
formatRaw = false;
columnWidth = length;
- userInfoOutput("Command was successfull");
- }
- else {
+ userInfoOutput("Command was successful");
+ } else {
System.err.println("Minimum length has to be greater than 0");
}
}
@@ -115,10 +108,9 @@ public class TextOutput {
* @param index ArrayList with words and in which part they have
*/
public void indexOutput(ArrayList index) {
- if(index.size() == 0) {
+ if (index.size() == 0) {
userInfoOutput("index empty");
- }
- else {
+ } else {
for (String word : index) {
System.out.println(word);
}
diff --git a/test/TextOutputTest.java b/test/TextOutputTest.java
index 17d72b9..6c83487 100644
--- a/test/TextOutputTest.java
+++ b/test/TextOutputTest.java
@@ -1,29 +1,36 @@
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
-
import java.util.ArrayList;
+/**
+ * New class TextOutputTest
+ * This class is here to test the class TextOutput and to test the console output of that class.
+ * Author: Leonardo Brandenberger
+ * Date: 12.11.2021
+ */
class TextOutputTest {
TextOutput textOutput;
ArrayList text;
+ /**
+ * This method is here as a preparation for the test.
+ */
@BeforeEach
public void setup() {
textOutput = new TextOutput();
textOutput.formatFix(20);
- //textOutput.formatRaw();
text = new ArrayList<>();
text.add("Virtute praecedunt, quod fere cotidianis proeliis cum Germanis contendunt, septentr ionesimmensoslongusw ordos.");
text.add("Virtutedasjdhashdkjhakjdhakdshjkashd praecedunt, quod fere cotidianis proeliis cum");
- //text.add("ordos.");
text.add("1234");
text.add("12417575147517845 445264565");
text.add(" ");
- //text.add("1eeeeeee8597389751");
- //text.add("TextTextTextTextTextTextTextTextTextTextTextTextTextText TextTextTextTextTextTextTextTextTextTextTextText TextTextText");
}
+ /**
+ * This method is the test to show if the console output works as we expect it to.
+ */
@Test
public void print() {
textOutput.print(text);
diff --git a/test/TextTest.java b/test/TextTest.java
index 376dc42..61d1372 100644
--- a/test/TextTest.java
+++ b/test/TextTest.java
@@ -1,14 +1,25 @@
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
+
import java.util.ArrayList;
-
+/**
+ * New class TextTest
+ * This class is here to test the different methods of the Text class.
+ * Author: Roman Schenk, Andrin Fassbind
+ * Date: 12.11.2021
+ */
public class TextTest {
Text txt;
+ ArrayList stringListe;
+ /**
+ * This method is here as a preparation for the test.
+ */
@BeforeEach
void setup() {
+ stringListe = new ArrayList<>();
txt = new Text();
}
@@ -32,7 +43,6 @@ public class TextTest {
}
/**
- *
* Test Method del
*/
@Test
@@ -67,37 +77,44 @@ public class TextTest {
/**
* Test methode for Index method
+ * For TestCase Positiv Testcase One, Three and Four Negativ Testcase Two
*/
@Test
- void indexTest() {
- ArrayList stringListe;
-
- //Positiv Testcase One, Three and Four Negativ Testcase Two
+ void indexTestOne() {
txt.add("Word word Test");
txt.add("Word word etc. !!test zweite... Zeile");
txt.add("Lorem ipsum lorem ipsum TEST");
stringListe = txt.index();
- Assertions.assertEquals("Word 1, 2",stringListe.get(0));
- Assertions.assertEquals("Test 1, 2, 3",stringListe.get(1));
- //End of Test
-
- setup();
-
- //Positiv Testcase Two
- txt.add("Word word Word Test");
- stringListe = txt.index();
- Assertions.assertEquals("Word 1",stringListe.get(0));
- //End of Test
-
- setup();
-
- //Negativ Testcase One
- stringListe = txt.index();
- Assertions.assertEquals(0,stringListe.size());
+ Assertions.assertEquals("Word 1, 2", stringListe.get(0));
+ Assertions.assertEquals("Test 1, 2, 3", stringListe.get(1));
}
+ /**
+ * Test methode for Index method
+ * For TestCase Positiv Testcase Two
+ */
@Test
- void testing() {
+ void indexTestTwo() {
+ txt.add("\"Word word Word Test");
+ stringListe = txt.index();
+ Assertions.assertEquals("Word 1", stringListe.get(0));
+ }
+
+ /**
+ * Test methode for Index method
+ * For TestCase Negativ Testcase One
+ */
+ @Test
+ void indexTestThree() {
+ stringListe = txt.index();
+ Assertions.assertEquals(0, stringListe.size());
+ }
+
+ /**
+ * Test Method to check if index is working with empty Strings
+ */
+ @Test
+ void indexTestFour() {
txt.add("");
txt.index();
}
diff --git a/src/TextLogik.java b/src/TextLogic.java
similarity index 90%
rename from src/TextLogik.java
rename to src/TextLogic.java
index 376ed96..f3feb4e 100644
--- a/src/TextLogik.java
+++ b/src/TextLogic.java
@@ -1,13 +1,23 @@
-public class TextLogik {
+/**
+ * New class TextLogic
+ * This class defines the commands and initiates the methods of the Text class and TextOutput class.
+ * Authors: Michael Ziegler, Stefan Amador
+ * Date: 12.11.2021
+ */
+public class TextLogic {
+
+ /**
+ * The DataFields text and textOutput save the objects that are being used later in this class.
+ */
private final Text text;
private final TextOutput textOutput;
/**
* Initiates a new instance of the class TextLogik.
* Contains command instructions for the class Text.
* Defined the different cases and appointed to specific commands.
*/
- public TextLogik() {
+ public TextLogic() {
text = new Text();
textOutput = new TextOutput();
String[] command;
@@ -22,7 +32,7 @@ public class TextLogik {
switch (command[0]) {
case "ADD":
String inputText = "";
- while(inputText.length() == 0) {
+ while (inputText.length() == 0) {
textOutput.userInfoOutput("Please enter your text: ");
inputText = TextInput.getTextInput();
}
@@ -1,13 +1,23 @@
private final TextOutput textOutput;
/**
- * Initiates a new instance of the class TextLogik.
+ * Initiates a new instance of the class TextLogic.
* Contains command instructions for the class Text.
* Defined the different cases and appointed to specific commands.